## 0.4.0 (2025-04-08)

### Feat

- **slack**: add option to ignore professor-only menu items in cafeteria menu

### Fix

- **core**: update URL scheme from HTTP to HTTPS

[main 216addf] bump: version 0.3.2 → 0.4.0
 2 files changed, 2 insertions(+), 2 deletions(-)

